<?php
namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Est32000GiroDeEstoqueController extends \Teknisa\EST\Controllers\TeknisaCrud {

    protected $dataSourceName = "produto_posestdia_itlanctoest";
    protected $parameterBagColumns = ['CDFILIAL',
'CDALMOXARIFE',
'CDLOCALESTOQ',
'CDPRODINI',
'CDPRODFIN',
'NRDIAS',
'ORDENA',
'PARAM',
'DATAINI',
'DATAFIN',
'NRORG'];

    public function __construct($crudService, $parameterBag) {
        parent::__construct($crudService, $parameterBag);
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $filterPopup = $request->getFilterCriteria()->getConditions();
        
        $conditions =  array();
        $newFilterCriteria = new FilterCriteria('produto_posestdia_itlanctoest', $conditions);
        $newFilterCriteria->setDataSourceName('produto_posestdia_itlanctoest');
        $newFilterCriteria->addCondition('CDFILIAL',    $filterPopup[0]['value']);
        $newFilterCriteria->addCondition('CDALMOXARIFE',$filterPopup[1]['value']);
        $newFilterCriteria->addCondition('CDLOCALESTOQ',$filterPopup[2]['value']);
        $newFilterCriteria->addCondition('CDPRODINI',   $filterPopup[3]['value']);
        $newFilterCriteria->addCondition('CDPRODFIN',   $filterPopup[4]['value']);
        $newFilterCriteria->addCondition('NRDIAS',      $filterPopup[5]['value']);
        $newFilterCriteria->addCondition('ORDENA',      $filterPopup[6]['value']);
        $newFilterCriteria->addCondition('PARAM',       $filterPopup[7]['value']);
        $newFilterCriteria->addCondition('DATAINI',     $filterPopup[8]['value']);
        $newFilterCriteria->addCondition('DATAFIN',     $filterPopup[9]['value']);
        
        $giroParameterBagColumns = ["CDFILIAL", "CDALMOXARIFE", "CDLOCALESTOQ", "CDPRODINI", "CDPRODFIN", "NRDIAS", "ORDENA", "PARAM", "DATAINI", "DATAFIN"];
        // $newFilterCriteria = $this->crudService->getFilterCriteriaWithNrOrg($newFilterCriteria);
        $populatedFilterCriteria = $this->crudService->getPopulatedFilterCriteria($newFilterCriteria, $giroParameterBagColumns);

        $newResponse = new DTO\Response;
        $this->crudService->find($newResponse, $populatedFilterCriteria);
        $dataSets = $newResponse->getDataSets();
        
        $rows = $dataSets[0]->getRows();
        
        if(count($rows) > 0){
            $newRows = $this->buildValorTotal($rows, $filterPopup);
        }else{
            $newRows = $rows;
        }

        $newDataSet = $this->buildDataSet($this->dataSourceName, $newRows);
        $response->setDataSets(array($newDataSet));
    }
    
    public function buildValorTotal($rows, $filterPopup){
        
        $qtdeProdutos = count($rows);
        if($qtdeProdutos > 0){
            
            $dadospor = $filterPopup[10]['value'];
            $nrdias = $filterPopup[5]['value'];
            
            
            $totQTESTOQDIA = 0;
            $totQTLANCTOEST = 0;
            $totVRESTOQDIA = 0;
            $totVRTOTLANCTO = 0;
            $totDIASRESTANTES = 0;
            
            for($i=0; count($rows) > $i; $i++){
                $totQTESTOQDIA += $rows[$i]['QTESTOQDIA'];
                $totQTLANCTOEST += $rows[$i]['QTLANCTOEST'];
                $totVRESTOQDIA += $rows[$i]['VRESTOQDIA'];
                $totVRTOTLANCTO += $rows[$i]['VRTOTLANCTO'];
                $totDIASRESTANTES += $rows[$i]['DIASRESTANTES'];
            }
            
            $mediaDias = $totDIASRESTANTES / $qtdeProdutos;
            
            if($dadospor == '1'){
                $newRow = [
                    "QTESTOQDIA"    => $totQTESTOQDIA,
                    "QTLANCTOEST"   => $totQTLANCTOEST,
                    "DIASRESTANTES" => null,
                    "CDLOCALESTOQ"  => "Totais"
                ];
                array_push($rows, $newRow);
            }else{
                $newRow = [
                    "VRESTOQDIA"    => $totVRESTOQDIA,
                    "VRTOTLANCTO"   => $totVRTOTLANCTO,
                    "DIASRESTANTES" => null,
                    "CDLOCALESTOQ"  => "Totais"
                ];
                array_push($rows, $newRow);
            }
            
            $newRow = [
                "QTESTOQDIA"    => null,
                "QTLANCTOEST"   => null,
                "VRESTOQDIA"    => null,
                "VRTOTLANCTO"   => null,
                "DIASRESTANTES" => $mediaDias,
                "CDLOCALESTOQ"  => "Nº médio de dias"
            ];
            array_push($rows, $newRow);
            
            if($dadospor == '1'){
                $qtdeMediaDia = ($totQTESTOQDIA/$totQTLANCTOEST)*$nrdias;
                $newRow = [
                    "QTESTOQDIA"    => null,
                    "QTLANCTOEST"   => null,
                    "VRESTOQDIA"    => null,
                    "VRTOTLANCTO"   => null,
                    "DIASRESTANTES" => $qtdeMediaDia,
                    "CDLOCALESTOQ"  => "Qtde. média dia"
                ];
                array_push($rows, $newRow);
            }else{
                $vrMediaDia = ($totVRESTOQDIA/$totVRTOTLANCTO)*$nrdias;
                $newRow = [
                    "QTESTOQDIA"    => null,
                    "QTLANCTOEST"   => null,
                    "VRESTOQDIA"    => null,
                    "VRTOTLANCTO"   => null,
                    "DIASRESTANTES" => $vrMediaDia,
                    "CDLOCALESTOQ"  => "Valor médio dia"
                ];
                array_push($rows, $newRow);
            }
            
            return $rows;
        }
    }
    
    public function buildDataSet($dataSourceName, $rows){
        $dataSet = new DataSet($dataSourceName, $rows);
        return $dataSet;
    }
}